From f6bc6ed2dec9cd60853db928fa6e56a92ab5de0d Mon Sep 17 00:00:00 2001
From: WXL <1785969728@qq.com>
Date: 星期三, 12 二月 2025 11:07:17 +0800
Subject: [PATCH] 测试完成

---
 src/views/login.vue |   47 +++++++++++++++++++++++++++++++++++------------
 1 files changed, 35 insertions(+), 12 deletions(-)

diff --git a/src/views/login.vue b/src/views/login.vue
index 9a160c8..3b58d3a 100644
--- a/src/views/login.vue
+++ b/src/views/login.vue
@@ -6,7 +6,7 @@
       :rules="loginRules"
       class="login-form"
     >
-      <h3 class="title">娴欎腑澶т簩闄㈡櫤鎱ч殢璁垮钩鍙�</h3>
+      <h3 class="title">娴欎腑鍖诲ぇ浜岄櫌鏅烘収闅忚骞冲彴</h3>
       <el-form-item prop="username">
         <el-input
           v-model="loginForm.username"
@@ -36,6 +36,19 @@
           />
         </el-input>
       </el-form-item>
+      <!-- 涓�===================姘� -->
+      <!-- <el-form-item prop="orgid">
+        <el-select style="width: 100%;" v-model="loginForm.orgid"  placeholder="璇烽�夋嫨闄㈠尯">
+          <el-option
+            v-for="item in options"
+            :key="item.value"
+            :label="item.label"
+            :value="item.value"
+          >
+          </el-option>
+          <i slot="prefix" class="el-icon-mobile"></i>
+        </el-select>
+      </el-form-item> -->
       <!-- <el-form-item prop="code" v-if="captchaEnabled">
         <el-input
           v-model="loginForm.code"
@@ -99,8 +112,12 @@
         password: "",
         rememberMe: false,
         code: "",
-        uuid: "",
+        orgid:'1',
       },
+      options: [
+        { value: "1", label: "鏅畞鐣叉棌鑷不鍘夸汉姘戝尰闄�" },
+        { value: "2", label: "涓芥按甯備腑鍖婚櫌" },
+       ],
       loginRules: {
         username: [
           { required: true, trigger: "blur", message: "璇疯緭鍏ユ偍鐨勮处鍙�" },
@@ -108,7 +125,7 @@
         password: [
           { required: true, trigger: "blur", message: "璇疯緭鍏ユ偍鐨勫瘑鐮�" },
         ],
         // code: [{ required: true, trigger: "change", message: "璇疯緭鍏ラ獙璇佺爜" }],
       },
       loading: false,
       // 楠岃瘉鐮佸紑鍏�
@@ -129,6 +146,9 @@
   created() {
     this.getCode();
     this.getCookie();
+    // if (localStorage.getItem('orgid')) {
+    //   this.loginForm.orgid = localStorage.getItem('orgid');
+    // }
   },
   methods: {
     getCode() {
@@ -170,10 +190,12 @@
             Cookies.remove("password");
             Cookies.remove("rememberMe");
           }
+          this.loginForm.orgid = '1',
           this.$store
             .dispatch("Login", this.loginForm)
             .then(() => {
-              this.$router.push({ path: this.redirect || "/" }).catch(() => {});
+              // this.$router.push({ path: this.redirect || "/" }).catch(() => {});
+              this.$router.push({ path:"/patient/patient" }).catch(() => {});
             })
             .catch(() => {
               this.loading = false;
@@ -194,17 +216,17 @@
   justify-content: center;
   align-items: center;
   height: 100%;
-  overflow:hidden !important;
+  overflow: hidden !important;
   background-position: center center;
 
   /* 鑳屾櫙鍥句笉骞抽摵 */
-background-repeat: no-repeat;
-/* 褰撳唴瀹归珮搴﹀ぇ浜庡浘鐗囬珮搴︽椂锛岃儗鏅浘鍍忕殑浣嶇疆鐩稿浜巚iewport鍥哄畾 */
-background-attachment: fixed;
-/* 璁╄儗鏅浘鍩轰簬瀹瑰櫒澶у皬浼哥缉 */
-background-size: cover;
-/* 璁剧疆鑳屾櫙棰滆壊锛岃儗鏅浘鍔犺浇杩囩▼涓細鏄剧ず鑳屾櫙鑹� */
-background-color: #464646;
+  background-repeat: no-repeat;
+  /* 褰撳唴瀹归珮搴﹀ぇ浜庡浘鐗囬珮搴︽椂锛岃儗鏅浘鍍忕殑浣嶇疆鐩稿浜巚iewport鍥哄畾 */
+  background-attachment: fixed;
+  /* 璁╄儗鏅浘鍩轰簬瀹瑰櫒澶у皬浼哥缉 */
+  background-size: cover;
+  /* 璁剧疆鑳屾櫙棰滆壊锛岃儗鏅浘鍔犺浇杩囩▼涓細鏄剧ず鑳屾櫙鑹� */
+  background-color: #464646;
   background-image: url("../assets/images/login-background.jpg");
   background-size: cover;
 }
@@ -257,6 +279,7 @@
   font-size: 12px;
   letter-spacing: 1px;
 }
+
 .login-code-img {
   height: 38px;
 }
@@ -108,7 +125,7 @@
           { required: true, trigger: "blur", message: "璇疯緭鍏ユ偍鐨勫瘑鐮�" },
         ],
-        // code: [{ required: true, trigger: "change", message: "璇疯緭鍏ラ獙璇佺爜" }],
+        // orgid: [{ required: true, trigger: "blur", message: "璇烽�夋嫨闄㈠尯" }],
       },
       loading: false,

--
Gitblit v1.9.3